'use strict';

var through = require('through2');
var stylus  = require('accord').load('stylus');
var gutil   = require('gulp-util');
var rext    = require('replace-ext');
var path    = require('path');
var _       = require('lodash');

var PLUGIN_NAME = 'gulp-stylus';

module.exports = function (options) {
  var opts = _.cloneDeep(options) || {};

  _.defaults(opts, {
    paths: []
  });

  return through.obj(function (file, enc, cb) {

    if (file.isStream()) {
      return cb(new gutil.PluginError(PLUGIN_NAME, 'Streaming not supported'));
    }
    if (file.isNull()){
      return cb(null, file);
    }
    if (path.extname(file.path) === '.css'){
      return cb(null, file);
    }
    opts.filename = file.path;
    opts.paths.push(path.dirname(file.path));

    stylus.render(file.contents.toString('utf8'), opts)
    .catch(function(err){
      return cb(new gutil.PluginError(PLUGIN_NAME, err));
    })
    .then(function(css){
      if (css !== undefined){
        file.path = rext(file.path, '.css');
        file.contents = new Buffer(css);
        return cb(null, file);
      }
    });
  });

};
